@@ -1,13 +1,14 @@
-import distutils.errors
-import urllib.request
-import urllib.error
 import http.client
-from unittest import mock
+import re
+import urllib.error
+import urllib.request
+from inspect import cleandoc
 
 import pytest
 
 import setuptools.package_index
-from .textwrap import DALS
+
+import distutils.errors
 
 
 class TestPackageIndex:
@@ -24,11 +25,8 @@ class TestPackageIndex:
     def test_bad_url_bad_port(self):
         index = setuptools.package_index.PackageIndex()
         url = 'http://127.0.0.1:0/nonesuch/test_package_index'
-        try:
+        with pytest.raises(Exception, match=re.escape(url)):
             v = index.open_url(url)
-        except Exception as exc:
-            assert url in str(exc)
-        else:
             assert isinstance(v, urllib.error.HTTPError)
 
     def test_bad_url_typo(self):
@@ -37,15 +35,10 @@ class TestPackageIndex:
         # in its home URL
         index = setuptools.package_index.PackageIndex(hosts=('www.example.com',))
 
-        url = (
-            'url:%20https://svn.plone.org/svn'
-            '/collective/inquant.contentmirror.plone/trunk'
-        )
-        try:
+        url = 'url:%20https://svn.plone.org/svn/collective/inquant.contentmirror.plone/trunk'
+
+        with pytest.raises(Exception, match=re.escape(url)):
             v = index.open_url(url)
-        except Exception as exc:
-            assert url in str(exc)
-        else:
             assert isinstance(v, urllib.error.HTTPError)
 
     def test_bad_url_bad_status_line(self):
@@ -56,12 +49,8 @@ class TestPackageIndex:
 
         index.opener = _urlopen
         url = 'http://example.com'
-        try:
+        with pytest.raises(Exception, match=r'line'):
             index.open_url(url)
-        except Exception as exc:
-            assert 'line' in str(exc)
-        else:
-            raise AssertionError('Should have raise here!')
 
     def test_bad_url_double_scheme(self):
         """
@@ -171,49 +160,46 @@ class TestPackageIndex:
             assert dists[0].version == ''
             assert dists[1].version == vc
 
-    def test_download_git_with_rev(self, tmpdir):
+    def test_download_git_with_rev(self, tmp_path, fp):
         url = 'git+https://github.example/group/project@master#egg=foo'
         index = setuptools.package_index.PackageIndex()
 
-        with mock.patch("os.system") as os_system_mock:
-            result = index.download(url, str(tmpdir))
+        expected_dir = tmp_path / 'project@master'
+        fp.register([
+            'git',
+            'clone',
+            '--quiet',
+            'https://github.example/group/project',
+            expected_dir,
+        ])
+        fp.register(['git', '-C', expected_dir, 'checkout', '--quiet', 'master'])
 
-        os_system_mock.assert_called()
+        result = index.download(url, tmp_path)
 
-        expected_dir = str(tmpdir / 'project@master')
-        expected = (
-            'git clone --quiet ' 'https://github.example/group/project {expected_dir}'
-        ).format(**locals())
-        first_call_args = os_system_mock.call_args_list[0][0]
-        assert first_call_args == (expected,)
+        assert result == str(expected_dir)
+        assert len(fp.calls) == 2
 
-        tmpl = 'git -C {expected_dir} checkout --quiet master'
-        expected = tmpl.format(**locals())
-        assert os_system_mock.call_args_list[1][0] == (expected,)
-        assert result == expected_dir
-
-    def test_download_git_no_rev(self, tmpdir):
+    def test_download_git_no_rev(self, tmp_path, fp):
         url = 'git+https://github.example/group/project#egg=foo'
         index = setuptools.package_index.PackageIndex()
 
-        with mock.patch("os.system") as os_system_mock:
-            result = index.download(url, str(tmpdir))
+        expected_dir = tmp_path / 'project'
+        fp.register([
+            'git',
+            'clone',
+            '--quiet',
+            'https://github.example/group/project',
+            expected_dir,
+        ])
+        index.download(url, tmp_path)
 
-        os_system_mock.assert_called()
-
-        expected_dir = str(tmpdir / 'project')
-        expected = (
-            'git clone --quiet ' 'https://github.example/group/project {expected_dir}'
-        ).format(**locals())
-        os_system_mock.assert_called_once_with(expected)
-
-    def test_download_svn(self, tmpdir):
+    def test_download_svn(self, tmp_path):
         url = 'svn+https://svn.example/project#egg=foo'
         index = setuptools.package_index.PackageIndex()
 
         msg = r".*SVN download is not supported.*"
         with pytest.raises(distutils.errors.DistutilsError, match=msg):
-            index.download(url, str(tmpdir))
+            index.download(url, tmp_path)
 
 
 class TestContentCheckers:
@@ -257,14 +243,15 @@ class TestPyPIConfig:
     def test_percent_in_password(self, tmp_home_dir):
         pypirc = tmp_home_dir / '.pypirc'
         pypirc.write_text(
-            DALS(
+            cleandoc(
                 """
-            [pypi]
-            repository=https://pypi.org
-            username=jaraco
-            password=pity%
-        """
-            )
+                [pypi]
+                repository=https://pypi.org
+                username=jaraco
+                password=pity%
+                """
+            ),
+            encoding="utf-8",
         )
         cfg = setuptools.package_index.PyPIConfig()
         cred = cfg.creds_by_repository['https://pypi.org']
